Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2829)

Unified Diff: chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc

Issue 2799093002: s/DidNavigateWithinPage/OnSameDocumentNavigation. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/content_settings_observer_browsertest.cc ('k') | content/public/test/render_view_test.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc
diff --git a/chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc b/chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc
index 2412c8457e286b36720edae37b14ed4d3ce3e53d..03783b5a39cc50707ba2c0a90208b3fb75ddda94 100644
--- a/chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc
+++ b/chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc
@@ -183,10 +183,10 @@ TEST_F(PhishingClassifierDelegateTest, Navigation) {
PageCaptured(&page_text, false, url);
Mock::VerifyAndClearExpectations(classifier_);
// Navigating within page works similarly to a subframe navigation, but
// see the TODO in PhishingClassifierDelegate::DidCommitProvisionalLoad.
EXPECT_CALL(*classifier_, CancelPendingClassification());
- DidNavigateWithinPage(GetMainFrame(), true, true);
+ OnSameDocumentNavigation(GetMainFrame(), true, true);
Mock::VerifyAndClearExpectations(classifier_);
OnStartPhishingDetection(url);
@@ -250,8 +250,8 @@ TEST_F(PhishingClassifierDelegateTest, Navigation) {
Mock::VerifyAndClearExpectations(classifier_);
EXPECT_CALL(*classifier_, CancelPendingClassification());
- // In-page navigation.
- DidNavigateWithinPage(GetMainFrame(), true, true);
+ // Same document navigation.
+ OnSameDocumentNavigation(GetMainFrame(), true, true);
Mock::VerifyAndClearExpectations(classifier_);
OnStartPhishingDetection(url);
« no previous file with comments | « chrome/renderer/content_settings_observer_browsertest.cc ('k') | content/public/test/render_view_test.h » ('j') | no next file with comments »
@@ -183,10 +183,10 @@ TEST_F(PhishingClassifierDelegateTest, Navigation) {
PageCaptured(&page_text, false, url);
Mock::VerifyAndClearExpectations(classifier_);
- // Navigating within page works similarly to a subframe navigation, but
- // see the TODO in PhishingClassifierDelegate::DidCommitProvisionalLoad.
+ // Same document navigation works similarly to a subframe navigation, but see
+ // the TODO in PhishingClassifierDelegate::DidCommitProvisionalLoad.
EXPECT_CALL(*classifier_, CancelPendingClassification());

Powered by Google App Engine
This is Rietveld 408576698